@@ -1,40 +1,17 @@
-# Copyright 2022 The TensorFlow Authors. All Rights Reserved.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-# ==============================================================================
-
-
-"""ConvNeXt models for Keras.
-
-References:
-
-- [A ConvNet for the 2020s](https://arxiv.org/abs/2201.03545)
-  (CVPR 2022)
-"""
-
 import numpy as np
-import tensorflow.compat.v2 as tf
 
 from keras.src import backend
 from keras.src import initializers
 from keras.src import layers
-from keras.src import utils
+from keras.src import ops
+from keras.src import random
+from keras.src.api_export import keras_export
 from keras.src.applications import imagenet_utils
-from keras.src.engine import sequential
-from keras.src.engine import training as training_lib
-
-# isort: off
-from tensorflow.python.util.tf_export import keras_export
+from keras.src.layers.layer import Layer
+from keras.src.models import Functional
+from keras.src.models import Sequential
+from keras.src.ops import operation_utils
+from keras.src.utils import file_utils
 
 BASE_WEIGHTS_PATH = (
     "https://storage.googleapis.com/tensorflow/keras-applications/convnext/"
@@ -94,73 +71,74 @@ MODEL_CONFIGS = {
 
 BASE_DOCSTRING = """Instantiates the {name} architecture.
 
-  References:
-    - [A ConvNet for the 2020s](https://arxiv.org/abs/2201.03545)
-    (CVPR 2022)
+References:
+- [A ConvNet for the 2020s](https://arxiv.org/abs/2201.03545)
+(CVPR 2022)
 
-  For image classification use cases, see
-  [this page for detailed examples](
-  https://keras.io/api/applications/#usage-examples-for-image-classification-models).
-  For transfer learning use cases, make sure to read the
-  [guide to transfer learning & fine-tuning](
-    https://keras.io/guides/transfer_learning/).
+For image classification use cases, see
+[this page for detailed examples](
+https://keras.io/api/applications/#usage-examples-for-image-classification-models).
+For transfer learning use cases, make sure to read the
+[guide to transfer learning & fine-tuning](
+https://keras.io/guides/transfer_learning/).
 
-  The `base`, `large`, and `xlarge` models were first pre-trained on the
-  ImageNet-21k dataset and then fine-tuned on the ImageNet-1k dataset. The
-  pre-trained parameters of the models were assembled from the
-  [official repository](https://github.com/facebookresearch/ConvNeXt). To get a
-  sense of how these parameters were converted to Keras compatible parameters,
-  please refer to
-  [this repository](https://github.com/sayakpaul/keras-convnext-conversion).
+The `base`, `large`, and `xlarge` models were first pre-trained on the
+ImageNet-21k dataset and then fine-tuned on the ImageNet-1k dataset. The
+pre-trained parameters of the models were assembled from the
+[official repository](https://github.com/facebookresearch/ConvNeXt). To get a
+sense of how these parameters were converted to Keras compatible parameters,
+please refer to
+[this repository](https://github.com/sayakpaul/keras-convnext-conversion).
 
-  Note: Each Keras Application expects a specific kind of input preprocessing.
-  For ConvNeXt, preprocessing is included in the model using a `Normalization`
-  layer.  ConvNeXt models expect their inputs to be float or uint8 tensors of
-  pixels with values in the [0-255] range.
+Note: Each Keras Application expects a specific kind of input preprocessing.
+For ConvNeXt, preprocessing is included in the model using a `Normalization`
+layer.  ConvNeXt models expect their inputs to be float or uint8 tensors of
+pixels with values in the [0-255] range.
 
-  When calling the `summary()` method after instantiating a ConvNeXt model,
-  prefer setting the `expand_nested` argument `summary()` to `True` to better
-  investigate the instantiated model.
+When calling the `summary()` method after instantiating a ConvNeXt model,
+prefer setting the `expand_nested` argument `summary()` to `True` to better
+investigate the instantiated model.
 
-  Args:
+Args:
     include_top: Whether to include the fully-connected
-      layer at the top of the network. Defaults to `True`.
+        layer at the top of the network. Defaults to `True`.
     weights: One of `None` (random initialization),
-      `"imagenet"` (pre-training on ImageNet-1k), or the path to the weights
-      file to be loaded. Defaults to `"imagenet"`.
+        `"imagenet"` (pre-training on ImageNet-1k), or the path to the weights
+        file to be loaded. Defaults to `"imagenet"`.
     input_tensor: Optional Keras tensor
-      (i.e. output of `layers.Input()`)
-      to use as image input for the model.
+        (i.e. output of `layers.Input()`)
+        to use as image input for the model.
     input_shape: Optional shape tuple, only to be specified
-      if `include_top` is False.
-      It should have exactly 3 inputs channels.
+        if `include_top` is `False`.
+        It should have exactly 3 inputs channels.
     pooling: Optional pooling mode for feature extraction
-      when `include_top` is `False`.
-      - `None` means that the output of the model will be
+        when `include_top` is `False`. Defaults to None.
+        - `None` means that the output of the model will be
         the 4D tensor output of the last convolutional layer.
-      - `avg` means that global average pooling
+        - `avg` means that global average pooling
         will be applied to the output of the
         last convolutional layer, and thus
         the output of the model will be a 2D tensor.
-      - `max` means that global max pooling will
+        - `max` means that global max pooling will
         be applied.
-      Defaults to `None`.
     classes: Optional number of classes to classify images
-      into, only to be specified if `include_top` is True, and
-      if no `weights` argument is specified. 1000 is how many
-      ImageNet classes there are. Defaults to `1000`.
+        into, only to be specified if `include_top` is `True`, and
+        if no `weights` argument is specified. Defaults to 1000 (number of
+        ImageNet classes).
     classifier_activation: A `str` or callable. The activation function to use
-      on the "top" layer. Ignored unless `include_top=True`. Set
-      `classifier_activation=None` to return the logits of the "top" layer.
-      When loading pretrained weights, `classifier_activation` can only
-      be `None` or `"softmax"`. Defaults to `"softmax"`.
+        on the "top" layer. Ignored unless `include_top=True`. Set
+        `classifier_activation=None` to return the logits of the "top" layer.
+        Defaults to `"softmax"`.
+        When loading pretrained weights, `classifier_activation` can only
+        be `None` or `"softmax"`.
+    name: The name of the model (string).
 
-  Returns:
-    A `keras.Model` instance.
+Returns:
+    A model instance.
 """
 
 
-class StochasticDepth(layers.Layer):
+class StochasticDepth(Layer):
     """Stochastic Depth module.
 
     It performs batch-wise dropping rather than sample-wise. In libraries like
@@ -168,7 +146,7 @@ class StochasticDepth(layers.Layer):
     sample-wise.
 
     References:
-      - https://github.com/rwightman/pytorch-image-models
+    - https://github.com/rwightman/pytorch-image-models
 
     Args:
       drop_path_rate (float): Probability of dropping paths. Should be within
@@ -185,9 +163,9 @@ class StochasticDepth(layers.Layer):
     def call(self, x, training=None):
         if training:
             keep_prob = 1 - self.drop_path_rate
-            shape = (tf.shape(x)[0],) + (1,) * (len(tf.shape(x)) - 1)
-            random_tensor = keep_prob + tf.random.uniform(shape, 0, 1)
-            random_tensor = tf.floor(random_tensor)
+            shape = (ops.shape(x)[0],) + (1,) * (len(ops.shape(x)) - 1)
+            random_tensor = keep_prob + random.uniform(shape, 0, 1)
+            random_tensor = ops.floor(random_tensor)
             return (x / keep_prob) * random_tensor
         return x
 
@@ -197,19 +175,20 @@ class StochasticDepth(layers.Layer):
         return config
 
 
-class LayerScale(layers.Layer):
+class LayerScale(Layer):
     """Layer scale module.
 
     References:
-      - https://arxiv.org/abs/2103.17239
+
+    - https://arxiv.org/abs/2103.17239
 
     Args:
-      init_values (float): Initial value for layer scale. Should be within
-        [0, 1].
-      projection_dim (int): Projection dimensionality.
+        init_values (float): Initial value for layer scale. Should be within
+            [0, 1].
+        projection_dim (int): Projection dimensionality.
 
     Returns:
-      Tensor multiplied to the scale.
+        Tensor multiplied to the scale.
     """
 
     def __init__(self, init_values, projection_dim, **kwargs):
@@ -217,9 +196,8 @@ class LayerScale(layers.Layer):
         self.init_values = init_values
         self.projection_dim = projection_dim
 
-    def build(self, input_shape):
+    def build(self, _):
         self.gamma = self.add_weight(
-            name="gamma",
             shape=(self.projection_dim,),
             initializer=initializers.Constant(self.init_values),
             trainable=True,
@@ -249,21 +227,21 @@ def ConvNeXtBlock(
     - https://github.com/facebookresearch/ConvNeXt/blob/main/models/convnext.py
 
     Notes:
-      In the original ConvNeXt implementation (linked above), the authors use
-      `Dense` layers for pointwise convolutions for increased efficiency.
-      Following that, this implementation also uses the same.
+        In the original ConvNeXt implementation (linked above), the authors use
+        `Dense` layers for pointwise convolutions for increased efficiency.
+        Following that, this implementation also uses the same.
 
     Args:
-      projection_dim (int): Number of filters for convolution layers. In the
-        ConvNeXt paper, this is referred to as projection dimension.
-      drop_path_rate (float): Probability of dropping paths. Should be within
-        [0, 1].
-      layer_scale_init_value (float): Layer scale value. Should be a small float
-        number.
-      name: name to path to the keras layer.
+        projection_dim (int): Number of filters for convolution layers. In the
+            ConvNeXt paper, this is referred to as projection dimension.
+        drop_path_rate (float): Probability of dropping paths. Should be within
+            [0, 1].
+        layer_scale_init_value (float): Layer scale value.
+            Should be a small float number.
+        name: name to path to the keras layer.
 
     Returns:
-      A function representing a ConvNeXtBlock block.
+        A function representing a ConvNeXtBlock block.
     """
     if name is None:
         name = "prestem" + str(backend.get_uid("prestem"))
@@ -302,14 +280,7 @@ def ConvNeXtBlock(
 
 
 def PreStem(name=None):
-    """Normalizes inputs with ImageNet-1k mean and std.
-
-    Args:
-      name (str): Name prefix.
-
-    Returns:
-      A presemt function.
-    """
+    """Normalizes inputs with ImageNet-1k mean and std."""
     if name is None:
         name = "prestem" + str(backend.get_uid("prestem"))
 
@@ -332,12 +303,12 @@ def Head(num_classes=1000, classifier_activation=None, name=None):
     """Implementation of classification head of ConvNeXt.
 
     Args:
-      num_classes: number of classes for Dense layer
-      classifier_activation: activation function for the Dense layer
-      name: name prefix
+        num_classes: number of classes for Dense layer
+        classifier_activation: activation function for the Dense layer
+        name: name prefix
 
     Returns:
-      Classification head function.
+        Classification head function.
     """
     if name is None:
         name = str(backend.get_uid("head"))
@@ -363,7 +334,7 @@ def ConvNeXt(
     drop_path_rate=0.0,
     layer_scale_init_value=1e-6,
     default_size=224,
-    model_name="convnext",
+    name="convnext",
     include_preprocessing=True,
     include_top=True,
     weights=None,
@@ -372,58 +343,61 @@ def ConvNeXt(
     pooling=None,
     classes=1000,
     classifier_activation="softmax",
+    weights_name=None,
 ):
     """Instantiates ConvNeXt architecture given specific configuration.
 
     Args:
-      depths: An iterable containing depths for each individual stages.
-      projection_dims: An iterable containing output number of channels of
-      each individual stages.
-      drop_path_rate: Stochastic depth probability. If 0.0, then stochastic
-        depth won't be used.
-      layer_scale_init_value: Layer scale coefficient. If 0.0, layer scaling
-        won't be used.
-      default_size: Default input image size.
-      model_name: An optional name for the model.
-      include_preprocessing: boolean denoting whther to include preprocessing in
-        the model. When `weights="imagenet"` this should be always set to True.
-        But for other models (e.g., randomly initialized) users should set it
-        to False and apply preprocessing to data accordingly.
-      include_top: Boolean denoting whether to include classification head to
-        the model.
-      weights: one of `None` (random initialization), `"imagenet"` (pre-training
-        on ImageNet-1k), or the path to the weights file to be loaded.
-      input_tensor: optional Keras tensor (i.e. output of `layers.Input()`) to
-        use as image input for the model.
-      input_shape: optional shape tuple, only to be specified if `include_top`
-        is False. It should have exactly 3 inputs channels.
-      pooling: optional pooling mode for feature extraction when `include_top`
-        is `False`.
-        - `None` means that the output of the model will be the 4D tensor output
-          of the last convolutional layer.
-        - `avg` means that global average pooling will be applied to the output
-          of the last convolutional layer, and thus the output of the model will
-          be a 2D tensor.
-        - `max` means that global max pooling will be applied.
-      classes: optional number of classes to classify images into, only to be
-        specified if `include_top` is True, and if no `weights` argument is
-        specified.
-      classifier_activation: A `str` or callable. The activation function to use
-        on the "top" layer. Ignored unless `include_top=True`. Set
-        `classifier_activation=None` to return the logits of the "top" layer.
+        depths: An iterable containing depths for each individual stages.
+        projection_dims: An iterable containing output number of channels of
+        each individual stages.
+        drop_path_rate: Stochastic depth probability. If 0.0, then stochastic
+            depth won't be used.
+        layer_scale_init_value: Layer scale coefficient. If 0.0, layer scaling
+            won't be used.
+        default_size: Default input image size.
+        name: An optional name for the model.
+        include_preprocessing: boolean denoting whther to
+            include preprocessing in the model.
+            When `weights="imagenet"` this should always be `True`.
+            But for other models (e.g., randomly initialized) you should set it
+            to `False` and apply preprocessing to data accordingly.
+        include_top: Boolean denoting whether to include classification
+            head to the model.
+        weights: one of `None` (random initialization), `"imagenet"`
+            (pre-training on ImageNet-1k),
+            or the path to the weights file to be loaded.
+        input_tensor: optional Keras tensor (i.e. output of `layers.Input()`) to
+            use as image input for the model.
+        input_shape: optional shape tuple, only to be specified if `include_top`
+            is `False`. It should have exactly 3 inputs channels.
+        pooling: optional pooling mode for feature extraction when `include_top`
+            is `False`.
+            - `None` means that the output of the model will be
+                the 4D tensor output of the last convolutional layer.
+            - `avg` means that global average pooling will be applied
+                to the output of the last convolutional layer,
+                and thus the output of the model will be a 2D tensor.
+            - `max` means that global max pooling will be applied.
+        classes: optional number of classes to classify images into,
+            only to be specified if `include_top` is `True`,
+            and if no `weights` argument is specified.
+        classifier_activation: A `str` or callable.
+            The activation function to use
+            on the "top" layer. Ignored unless `include_top=True`.
+            Set `classifier_activation=None` to return the logits
+            of the "top" layer.
 
     Returns:
-      A `keras.Model` instance.
-
-    Raises:
-        ValueError: in case of invalid argument for `weights`,
-          or invalid input shape.
-        ValueError: if `classifier_activation` is not `softmax`, or `None`
-          when using a pretrained top layer.
-        ValueError: if `include_top` is True but `num_classes` is not 1000
-          when using ImageNet.
+        A model instance.
     """
-    if not (weights in {"imagenet", None} or tf.io.gfile.exists(weights)):
+    if backend.image_data_format() == "channels_first":
+        raise ValueError(
+            "ConvNeXt does not support the `channels_first` image data "
+            "format. Switch to `channels_last` by editing your local "
+            "config file at ~/.keras/keras.json"
+        )
+    if not (weights in {"imagenet", None} or file_utils.exists(weights)):
         raise ValueError(
             "The `weights` argument should be either "
             "`None` (random initialization), `imagenet` "
@@ -433,8 +407,9 @@ def ConvNeXt(
 
     if weights == "imagenet" and include_top and classes != 1000:
         raise ValueError(
-            "If using `weights` as `'imagenet'` with `include_top`"
-            " as true, `classes` should be 1000"
+            'If using `weights="imagenet"` with `include_top=True`, '
+            "`classes` should be 1000. "
+            f"Received classes={classes}"
         )
 
     # Determine proper input shape.
@@ -456,7 +431,7 @@ def ConvNeXt(
             img_input = input_tensor
 
     if input_tensor is not None:
-        inputs = utils.layer_utils.get_source_inputs(input_tensor)[0]
+        inputs = operation_utils.get_source_inputs(input_tensor)[0]
     else:
         inputs = img_input
 
@@ -467,22 +442,22 @@ def ConvNeXt(
         )
         num_channels = input_shape[channel_axis - 1]
         if num_channels == 3:
-            x = PreStem(name=model_name)(x)
+            x = PreStem(name=name)(x)
 
     # Stem block.
-    stem = sequential.Sequential(
+    stem = Sequential(
         [
             layers.Conv2D(
                 projection_dims[0],
                 kernel_size=4,
                 strides=4,
-                name=model_name + "_stem_conv",
+                name=name + "_stem_conv",
             ),
             layers.LayerNormalization(
-                epsilon=1e-6, name=model_name + "_stem_layernorm"
+                epsilon=1e-6, name=name + "_stem_layernorm"
             ),
         ],
-        name=model_name + "_stem",
+        name=name + "_stem",
     )
 
     # Downsampling blocks.
@@ -491,20 +466,20 @@ def ConvNeXt(
 
     num_downsample_layers = 3
     for i in range(num_downsample_layers):
-        downsample_layer = sequential.Sequential(
+        downsample_layer = Sequential(
             [
                 layers.LayerNormalization(
                     epsilon=1e-6,
-                    name=model_name + "_downsampling_layernorm_" + str(i),
+                    name=name + "_downsampling_layernorm_" + str(i),
                 ),
                 layers.Conv2D(
                     projection_dims[i + 1],
                     kernel_size=2,
                     strides=2,
-                    name=model_name + "_downsampling_conv_" + str(i),
+                    name=name + "_downsampling_conv_" + str(i),
                 ),
             ],
-            name=model_name + "_downsampling_block_" + str(i),
+            name=name + "_downsampling_block_" + str(i),
         )
         downsample_layers.append(downsample_layer)
 
@@ -526,7 +501,7 @@ def ConvNeXt(
                 projection_dim=projection_dims[i],
                 drop_path_rate=depth_drop_rates[cur + j],
                 layer_scale_init_value=layer_scale_init_value,
-                name=model_name + f"_stage_{i}_block_{j}",
+                name=name + f"_stage_{i}_block_{j}",
             )(x)
         cur += depths[i]
 
@@ -535,7 +510,7 @@ def ConvNeXt(
         x = Head(
             num_classes=classes,
             classifier_activation=classifier_activation,
-            name=model_name,
+            name=name,
         )(x)
 
     else:
@@ -545,18 +520,18 @@ def ConvNeXt(
             x = layers.GlobalMaxPooling2D()(x)
         x = layers.LayerNormalization(epsilon=1e-6)(x)
 
-    model = training_lib.Model(inputs=inputs, outputs=x, name=model_name)
+    model = Functional(inputs=inputs, outputs=x, name=name)
 
     # Load weights.
     if weights == "imagenet":
         if include_top:
             file_suffix = ".h5"
-            file_hash = WEIGHTS_HASHES[model_name][0]
+            file_hash = WEIGHTS_HASHES[weights_name][0]
         else:
             file_suffix = "_notop.h5"
-            file_hash = WEIGHTS_HASHES[model_name][1]
-        file_name = model_name + file_suffix
-        weights_path = utils.data_utils.get_file(
+            file_hash = WEIGHTS_HASHES[weights_name][1]
+        file_name = name + file_suffix
+        weights_path = file_utils.get_file(
             file_name,
             BASE_WEIGHTS_PATH + file_name,
             cache_subdir="models",
@@ -573,11 +548,12 @@ def ConvNeXt(
 
 
 @keras_export(
-    "keras.applications.convnext.ConvNeXtTiny",
-    "keras.applications.ConvNeXtTiny",
+    [
+        "keras.applications.convnext.ConvNeXtTiny",
+        "keras.applications.ConvNeXtTiny",
+    ]
 )
 def ConvNeXtTiny(
-    model_name="convnext_tiny",
     include_top=True,
     include_preprocessing=True,
     weights="imagenet",
@@ -586,14 +562,16 @@ def ConvNeXtTiny(
     pooling=None,
     classes=1000,
     classifier_activation="softmax",
+    name="convnext_tiny",
 ):
     return ConvNeXt(
+        weights_name="convnext_tiny",
         depths=MODEL_CONFIGS["tiny"]["depths"],
         projection_dims=MODEL_CONFIGS["tiny"]["projection_dims"],
         drop_path_rate=0.0,
         layer_scale_init_value=1e-6,
         default_size=MODEL_CONFIGS["tiny"]["default_size"],
-        model_name=model_name,
+        name=name,
         include_top=include_top,
         include_preprocessing=include_preprocessing,
         weights=weights,
@@ -606,11 +584,12 @@ def ConvNeXtTiny(
 
 
 @keras_export(
-    "keras.applications.convnext.ConvNeXtSmall",
-    "keras.applications.ConvNeXtSmall",
+    [
+        "keras.applications.convnext.ConvNeXtSmall",
+        "keras.applications.ConvNeXtSmall",
+    ]
 )
 def ConvNeXtSmall(
-    model_name="convnext_small",
     include_top=True,
     include_preprocessing=True,
     weights="imagenet",
@@ -619,14 +598,16 @@ def ConvNeXtSmall(
     pooling=None,
     classes=1000,
     classifier_activation="softmax",
+    name="convnext_small",
 ):
     return ConvNeXt(
+        weights_name="convnext_small",
         depths=MODEL_CONFIGS["small"]["depths"],
         projection_dims=MODEL_CONFIGS["small"]["projection_dims"],
         drop_path_rate=0.0,
         layer_scale_init_value=1e-6,
         default_size=MODEL_CONFIGS["small"]["default_size"],
-        model_name=model_name,
+        name=name,
         include_top=include_top,
         include_preprocessing=include_preprocessing,
         weights=weights,
@@ -639,11 +620,12 @@ def ConvNeXtSmall(
 
 
 @keras_export(
-    "keras.applications.convnext.ConvNeXtBase",
-    "keras.applications.ConvNeXtBase",
+    [
+        "keras.applications.convnext.ConvNeXtBase",
+        "keras.applications.ConvNeXtBase",
+    ]
 )
 def ConvNeXtBase(
-    model_name="convnext_base",
     include_top=True,
     include_preprocessing=True,
     weights="imagenet",
@@ -652,14 +634,16 @@ def ConvNeXtBase(
     pooling=None,
     classes=1000,
     classifier_activation="softmax",
+    name="convnext_base",
 ):
     return ConvNeXt(
+        weights_name="convnext_base",
         depths=MODEL_CONFIGS["base"]["depths"],
         projection_dims=MODEL_CONFIGS["base"]["projection_dims"],
         drop_path_rate=0.0,
         layer_scale_init_value=1e-6,
         default_size=MODEL_CONFIGS["base"]["default_size"],
-        model_name=model_name,
+        name=name,
         include_top=include_top,
         include_preprocessing=include_preprocessing,
         weights=weights,
@@ -672,11 +656,12 @@ def ConvNeXtBase(
 
 
 @keras_export(
-    "keras.applications.convnext.ConvNeXtLarge",
-    "keras.applications.ConvNeXtLarge",
+    [
+        "keras.applications.convnext.ConvNeXtLarge",
+        "keras.applications.ConvNeXtLarge",
+    ]
 )
 def ConvNeXtLarge(
-    model_name="convnext_large",
     include_top=True,
     include_preprocessing=True,
     weights="imagenet",
@@ -685,14 +670,16 @@ def ConvNeXtLarge(
     pooling=None,
     classes=1000,
     classifier_activation="softmax",
+    name="convnext_large",
 ):
     return ConvNeXt(
+        weights_name="convnext_large",
         depths=MODEL_CONFIGS["large"]["depths"],
         projection_dims=MODEL_CONFIGS["large"]["projection_dims"],
         drop_path_rate=0.0,
         layer_scale_init_value=1e-6,
         default_size=MODEL_CONFIGS["large"]["default_size"],
-        model_name=model_name,
+        name=name,
         include_top=include_top,
         include_preprocessing=include_preprocessing,
         weights=weights,
@@ -705,11 +692,12 @@ def ConvNeXtLarge(
 
 
 @keras_export(
-    "keras.applications.convnext.ConvNeXtXLarge",
-    "keras.applications.ConvNeXtXLarge",
+    [
+        "keras.applications.convnext.ConvNeXtXLarge",
+        "keras.applications.ConvNeXtXLarge",
+    ]
 )
 def ConvNeXtXLarge(
-    model_name="convnext_xlarge",
     include_top=True,
     include_preprocessing=True,
     weights="imagenet",
@@ -718,14 +706,16 @@ def ConvNeXtXLarge(
     pooling=None,
     classes=1000,
     classifier_activation="softmax",
+    name="convnext_xlarge",
 ):
     return ConvNeXt(
+        weights_name="convnext_xlarge",
         depths=MODEL_CONFIGS["xlarge"]["depths"],
         projection_dims=MODEL_CONFIGS["xlarge"]["projection_dims"],
         drop_path_rate=0.0,
         layer_scale_init_value=1e-6,
         default_size=MODEL_CONFIGS["xlarge"]["default_size"],
-        model_name=model_name,
+        name=name,
         include_top=include_top,
         include_preprocessing=include_preprocessing,
         weights=weights,
@@ -754,14 +744,14 @@ def preprocess_input(x, data_format=None):
     placeholder to align the API surface between old and new version of model.
 
     Args:
-      x: A floating point `numpy.array` or a `tf.Tensor`.
-      data_format: Optional data format of the image tensor/array. `None` means
-        the global setting `tf.keras.backend.image_data_format()` is used
-        (unless you changed it, it uses "channels_last").
-        Defaults to `None`.
+        x: A floating point `numpy.array` or a tensor.
+        data_format: Optional data format of the image tensor/array. Defaults to
+            None, in which case the global setting
+            `keras.backend.image_data_format()` is used
+            (unless you changed it, it defaults to `"channels_last"`).{mode}
 
     Returns:
-      Unchanged `numpy.array` or `tf.Tensor`.
+        Unchanged `numpy.array` or tensor.
     """
     return x
 
@@ -772,4 +762,3 @@ def decode_predictions(preds, top=5):
 
 
 decode_predictions.__doc__ = imagenet_utils.decode_predictions.__doc__
-
