@@ -1,73 +1,61 @@
-# Copyright 2020 The TensorFlow Authors. All Rights Reserved.
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
-# ==============================================================================
-"""Keras image dataset loading utilities."""
-
-import multiprocessing
 import os
 import random
 import time
 import warnings
+from multiprocessing.pool import ThreadPool
 
 import numpy as np
-import tensorflow.compat.v2 as tf
 
+from keras.src import tree
+from keras.src.api_export import keras_export
 from keras.src.utils import io_utils
-
-# isort: off
-from tensorflow.python.util.tf_export import keras_export
+from keras.src.utils.module_utils import tensorflow as tf
 
 
-@keras_export("keras.utils.split_dataset", v1=[])
+@keras_export("keras.utils.split_dataset")
 def split_dataset(
     dataset, left_size=None, right_size=None, shuffle=False, seed=None
 ):
-    """Split a dataset into a left half and a right half (e.g. train / test).
+    """Splits a dataset into a left half and a right half (e.g. train / test).
 
     Args:
-        dataset: A `tf.data.Dataset` object, or a list/tuple of arrays with the
-          same length.
+        dataset:
+            A `tf.data.Dataset`, a `torch.utils.data.Dataset` object,
+            or a list/tuple of arrays with the same length.
         left_size: If float (in the range `[0, 1]`), it signifies
-          the fraction of the data to pack in the left dataset. If integer, it
-          signifies the number of samples to pack in the left dataset. If
-          `None`, it uses the complement to `right_size`. Defaults to `None`.
+            the fraction of the data to pack in the left dataset. If integer, it
+            signifies the number of samples to pack in the left dataset. If
+            `None`, defaults to the complement to `right_size`.
+            Defaults to `None`.
         right_size: If float (in the range `[0, 1]`), it signifies
-          the fraction of the data to pack in the right dataset. If integer, it
-          signifies the number of samples to pack in the right dataset. If
-          `None`, it uses the complement to `left_size`. Defaults to `None`.
+            the fraction of the data to pack in the right dataset.
+            If integer, it signifies the number of samples to pack
+            in the right dataset.
+            If `None`, defaults to the complement to `left_size`.
+            Defaults to `None`.
         shuffle: Boolean, whether to shuffle the data before splitting it.
         seed: A random seed for shuffling.
 
     Returns:
-        A tuple of two `tf.data.Dataset` objects: the left and right splits.
+        A tuple of two `tf.data.Dataset` objects:
+        the left and right splits.
 
     Example:
 
     >>> data = np.random.random(size=(1000, 4))
-    >>> left_ds, right_ds = tf.keras.utils.split_dataset(data, left_size=0.8)
+    >>> left_ds, right_ds = keras.utils.split_dataset(data, left_size=0.8)
     >>> int(left_ds.cardinality())
     800
     >>> int(right_ds.cardinality())
     200
-
     """
     dataset_type_spec = _get_type_spec(dataset)
 
-    if dataset_type_spec not in [tf.data.Dataset, list, tuple, np.ndarray]:
+    if dataset_type_spec is None:
         raise TypeError(
-            "The `dataset` argument must be either a `tf.data.Dataset` "
-            "object or a list/tuple of arrays. "
+            "The `dataset` argument must be either"
+            "a `tf.data.Dataset`, a `torch.utils.data.Dataset`"
+            "object, or a list/tuple of arrays. "
             f"Received: dataset={dataset} of type {type(dataset)}"
         )
 
@@ -113,7 +101,6 @@ def split_dataset(
 
     left_split = left_split.prefetch(tf.data.AUTOTUNE)
     right_split = right_split.prefetch(tf.data.AUTOTUNE)
-
     return left_split, right_split
 
 
@@ -123,20 +110,21 @@ def _convert_dataset_to_list(
     data_size_warning_flag=True,
     ensure_shape_similarity=True,
 ):
-    """Convert `tf.data.Dataset` object or list/tuple of NumPy arrays to a list.
+    """Convert `dataset` object to a list of samples.
 
     Args:
-        dataset : A `tf.data.Dataset` object or a list/tuple of arrays.
-        dataset_type_spec : the type of the dataset
-        data_size_warning_flag (bool, optional): If set to True, a warning will
-          be issued if the dataset takes longer than 10 seconds to iterate.
-          Defaults to `True`.
-        ensure_shape_similarity (bool, optional): If set to True, the shape of
-          the first sample will be used to validate the shape of rest of the
-          samples. Defaults to `True`.
+        dataset: A `tf.data.Dataset`, a `torch.utils.data.Dataset` object,
+            or a list/tuple of arrays.
+        dataset_type_spec: the type of the dataset.
+        data_size_warning_flag: If set to `True`, a warning will
+            be issued if the dataset takes longer than 10 seconds to iterate.
+            Defaults to `True`.
+        ensure_shape_similarity: If set to `True`, the shape of
+            the first sample will be used to validate the shape of rest of the
+            samples. Defaults to `True`.
 
     Returns:
-        List: A list of tuples/NumPy arrays.
+        List: A list of samples.
     """
     dataset_iterator = _get_data_iterator_from_dataset(
         dataset, dataset_type_spec
@@ -150,16 +138,7 @@ def _convert_dataset_to_list(
         data_size_warning_flag,
         start_time,
     ):
-        if dataset_type_spec in [tuple, list]:
-            # The try-except here is for NumPy 1.24 compatibility, see:
-            # https://numpy.org/neps/nep-0034-infer-dtype-is-object.html
-            try:
-                arr = np.array(sample)
-            except ValueError:
-                arr = np.array(sample, dtype=object)
-            dataset_as_list.append(arr)
-        else:
-            dataset_as_list.append(sample)
+        dataset_as_list.append(sample)
 
     return dataset_as_list
 
@@ -168,16 +147,9 @@ def _get_data_iterator_from_dataset(dataset, dataset_type_spec):
     """Get the iterator from a dataset.
 
     Args:
-        dataset :  A `tf.data.Dataset` object or a list/tuple of arrays.
-        dataset_type_spec : the type of the dataset
-
-    Raises:
-        ValueError:
-                  - If the dataset is empty.
-                  - If the dataset is not a `tf.data.Dataset` object
-                    or a list/tuple of arrays.
-                  - If the dataset is a list/tuple of arrays and the
-                    length of the list/tuple is not equal to the number
+        dataset: A `tf.data.Dataset`, a `torch.utils.data.Dataset` object,
+            or a list/tuple of arrays.
+        dataset_type_spec: The type of the dataset.
 
     Returns:
         iterator: An `iterator` object.
@@ -189,23 +161,23 @@ def _get_data_iterator_from_dataset(dataset, dataset_type_spec):
                 "Please provide a non-empty list of arrays."
             )
 
-        if _get_type_spec(dataset[0]) is np.ndarray:
-            expected_shape = dataset[0].shape
-            for i, element in enumerate(dataset):
-                if np.array(element).shape[0] != expected_shape[0]:
-                    raise ValueError(
-                        "Received a list of NumPy arrays with different "
-                        f"lengths. Mismatch found at index {i}, "
-                        f"Expected shape={expected_shape} "
-                        f"Received shape={np.array(element).shape}."
-                        "Please provide a list of NumPy arrays with "
-                        "the same length."
-                    )
-        else:
-            raise ValueError(
-                "Expected a list of `numpy.ndarray` objects,"
-                f"Received: {type(dataset[0])}"
-            )
+        expected_shape = None
+        for i, element in enumerate(dataset):
+            if not isinstance(element, np.ndarray):
+                raise ValueError(
+                    "Expected a list of `numpy.ndarray` objects,"
+                    f"Received: {type(element)} at index {i}."
+                )
+            if expected_shape is None:
+                expected_shape = element.shape
+            elif element.shape[0] != expected_shape[0]:
+                raise ValueError(
+                    "Received a list of NumPy arrays with different lengths."
+                    f"Mismatch found at index {i}, "
+                    f"Expected shape={expected_shape} "
+                    f"Received shape={np.array(element).shape}."
+                    "Please provide a list of NumPy arrays of the same length."
+                )
 
         return iter(zip(*dataset))
     elif dataset_type_spec == tuple:
@@ -215,31 +187,35 @@ def _get_data_iterator_from_dataset(dataset, dataset_type_spec):
                 "Please provide a non-empty tuple of arrays."
             )
 
-        if _get_type_spec(dataset[0]) is np.ndarray:
-            expected_shape = dataset[0].shape
-            for i, element in enumerate(dataset):
-                if np.array(element).shape[0] != expected_shape[0]:
-                    raise ValueError(
-                        "Received a tuple of NumPy arrays with different "
-                        f"lengths. Mismatch found at index {i}, "
-                        f"Expected shape={expected_shape} "
-                        f"Received shape={np.array(element).shape}."
-                        "Please provide a tuple of NumPy arrays with "
-                        "the same length."
-                    )
-        else:
-            raise ValueError(
-                "Expected a tuple of `numpy.ndarray` objects, "
-                f"Received: {type(dataset[0])}"
-            )
+        expected_shape = None
+        for i, element in enumerate(dataset):
+            if not isinstance(element, np.ndarray):
+                raise ValueError(
+                    "Expected a tuple of `numpy.ndarray` objects,"
+                    f"Received: {type(element)} at index {i}."
+                )
+            if expected_shape is None:
+                expected_shape = element.shape
+            elif element.shape[0] != expected_shape[0]:
+                raise ValueError(
+                    "Received a tuple of NumPy arrays with different lengths."
+                    f"Mismatch found at index {i}, "
+                    f"Expected shape={expected_shape} "
+                    f"Received shape={np.array(element).shape}."
+                    "Please provide a tuple of NumPy arrays of the same length."
+                )
 
         return iter(zip(*dataset))
     elif dataset_type_spec == tf.data.Dataset:
         if is_batched(dataset):
             dataset = dataset.unbatch()
         return iter(dataset)
+
+    elif is_torch_dataset(dataset):
+        return iter(dataset)
     elif dataset_type_spec == np.ndarray:
         return iter(dataset)
+    raise ValueError(f"Invalid dataset_type_spec: {dataset_type_spec}")
 
 
 def _get_next_sample(
@@ -248,32 +224,32 @@ def _get_next_sample(
     data_size_warning_flag,
     start_time,
 ):
-    """ "Yield data samples from the `dataset_iterator`.
+    """Yield data samples from the `dataset_iterator`.
 
     Args:
-        dataset_iterator : An `iterator` object.
-        ensure_shape_similarity (bool, optional): If set to True, the shape of
-          the first sample will be used to validate the shape of rest of the
-          samples. Defaults to `True`.
-        data_size_warning_flag (bool, optional): If set to True, a warning will
-          be issued if the dataset takes longer than 10 seconds to iterate.
-          Defaults to `True`.
+        dataset_iterator: An `iterator` object.
+        ensure_shape_similarity: If set to `True`, the shape of
+            the first sample will be used to validate the shape of rest of the
+            samples. Defaults to `True`.
+        data_size_warning_flag: If set to `True`, a warning will
+            be issued if the dataset takes longer than 10 seconds to iterate.
+            Defaults to `True`.
         start_time (float): the start time of the dataset iteration. this is
-          used only if `data_size_warning_flag` is set to true.
-
-    Raises:
-        ValueError: - If the dataset is empty.
-                    - If `ensure_shape_similarity` is set to True and the
-                      shape of the first sample is not equal to the shape of
-                      atleast one of the rest of the samples.
+            used only if `data_size_warning_flag` is set to true.
 
     Yields:
-        data_sample: A tuple/list of numpy arrays.
+        data_sample: The next sample.
     """
+    from keras.src.trainers.data_adapters.data_adapter_utils import (
+        is_torch_tensor,
+    )
+
     try:
         dataset_iterator = iter(dataset_iterator)
         first_sample = next(dataset_iterator)
-        if isinstance(first_sample, (tf.Tensor, np.ndarray)):
+        if isinstance(first_sample, (tf.Tensor, np.ndarray)) or is_torch_tensor(
+            first_sample
+        ):
             first_sample_shape = np.array(first_sample).shape
         else:
             first_sample_shape = None
@@ -281,7 +257,7 @@ def _get_next_sample(
         yield first_sample
     except StopIteration:
         raise ValueError(
-            "Received an empty Dataset. `dataset` must "
+            "Received an empty dataset. Argument `dataset` must "
             "be a non-empty list/tuple of `numpy.ndarray` objects "
             "or `tf.data.Dataset` objects."
         )
@@ -313,25 +289,14 @@ def _get_next_sample(
         yield sample
 
 
-def _restore_dataset_from_list(
-    dataset_as_list, dataset_type_spec, original_dataset
-):
-    """Restore the dataset from the list of arrays."""
-    if dataset_type_spec in [tuple, list]:
-        return tuple(np.array(sample) for sample in zip(*dataset_as_list))
-    elif dataset_type_spec == tf.data.Dataset:
-        if isinstance(original_dataset.element_spec, dict):
-            restored_dataset = {}
-            for d in dataset_as_list:
-                for k, v in d.items():
-                    if k not in restored_dataset:
-                        restored_dataset[k] = [v]
-                    else:
-                        restored_dataset[k].append(v)
-            return restored_dataset
-        else:
-            return tuple(np.array(sample) for sample in zip(*dataset_as_list))
-    return dataset_as_list
+def is_torch_dataset(dataset):
+    if hasattr(dataset, "__class__"):
+        for parent in dataset.__class__.__mro__:
+            if parent.__name__ == "Dataset" and str(
+                parent.__module__
+            ).startswith("torch.utils.data"):
+                return True
+    return False
 
 
 def _rescale_dataset_split_sizes(left_size, right_size, total_length):
@@ -341,17 +306,12 @@ def _rescale_dataset_split_sizes(left_size, right_size, total_length):
     the split sizes is equal to the total length of the dataset.
 
     Args:
-        left_size : The size of the left dataset split.
-        right_size : The size of the right dataset split.
-        total_length : The total length of the dataset.
-
-    Raises:
-        TypeError: - If `left_size` or `right_size` is not an integer or float.
-        ValueError: - If `left_size` or `right_size` is negative or greater
-                      than 1 or greater than `total_length`.
+        left_size: The size of the left dataset split.
+        right_size: The size of the right dataset split.
+        total_length: The total length of the dataset.
 
     Returns:
-        tuple: A tuple of rescaled left_size and right_size
+        tuple: A tuple of rescaled `left_size` and `right_size` integers.
     """
     left_size_type = type(left_size)
     right_size_type = type(right_size)
@@ -464,6 +424,44 @@ def _rescale_dataset_split_sizes(left_size, right_size, total_length):
     return left_size, right_size
 
 
+def _restore_dataset_from_list(
+    dataset_as_list, dataset_type_spec, original_dataset
+):
+    """Restore the dataset from the list of arrays."""
+    if dataset_type_spec in [tuple, list, tf.data.Dataset] or is_torch_dataset(
+        original_dataset
+    ):
+        # Save structure by taking the first element.
+        element_spec = dataset_as_list[0]
+        # Flatten each element.
+        dataset_as_list = [tree.flatten(sample) for sample in dataset_as_list]
+        # Combine respective elements at all indices.
+        dataset_as_list = [np.array(sample) for sample in zip(*dataset_as_list)]
+        # Recreate the original structure of elements.
+        dataset_as_list = tree.pack_sequence_as(element_spec, dataset_as_list)
+        # Turn lists to tuples as tf.data will fail on lists.
+        return tree.traverse(
+            lambda x: tuple(x) if isinstance(x, list) else x,
+            dataset_as_list,
+            top_down=False,
+        )
+
+    return dataset_as_list
+
+
+def is_batched(dataset):
+    """Check if the `tf.data.Dataset` is batched."""
+    return hasattr(dataset, "_batch_size")
+
+
+def get_batch_size(dataset):
+    """Get the batch size of the dataset."""
+    if is_batched(dataset):
+        return dataset._batch_size
+    else:
+        return None
+
+
 def _get_type_spec(dataset):
     """Get the type spec of the dataset."""
     if isinstance(dataset, tuple):
@@ -472,23 +470,12 @@ def _get_type_spec(dataset):
         return list
     elif isinstance(dataset, np.ndarray):
         return np.ndarray
-    elif isinstance(dataset, dict):
-        return dict
     elif isinstance(dataset, tf.data.Dataset):
         return tf.data.Dataset
-    else:
-        return None
+    elif is_torch_dataset(dataset):
+        from torch.utils.data import Dataset as TorchDataset
 
-
-def is_batched(tf_dataset):
-    """ "Check if the `tf.data.Dataset` is batched."""
-    return hasattr(tf_dataset, "_batch_size")
-
-
-def get_batch_size(tf_dataset):
-    """Get the batch size of the dataset."""
-    if is_batched(tf_dataset):
-        return tf_dataset._batch_size
+        return TorchDataset
     else:
         return None
 
@@ -501,43 +488,44 @@ def index_directory(
     shuffle=True,
     seed=None,
     follow_links=False,
+    verbose=True,
 ):
-    """Make list of all files in `directory`, with their labels.
+    """List all files in `directory`, with their labels.
 
     Args:
-      directory: Directory where the data is located.
-          If `labels` is "inferred", it should contain
-          subdirectories, each containing files for a class.
-          Otherwise, the directory structure is ignored.
-      labels: Either "inferred"
-          (labels are generated from the directory structure),
-          None (no labels),
-          or a list/tuple of integer labels of the same size as the number of
-          valid files found in the directory. Labels should be sorted according
-          to the alphanumeric order of the image file paths
-          (obtained via `os.walk(directory)` in Python).
-      formats: Allowlist of file extensions to index (e.g. ".jpg", ".txt").
-      class_names: Only valid if "labels" is "inferred". This is the explicit
-          list of class names (must match names of subdirectories). Used
-          to control the order of the classes
-          (otherwise alphanumerical order is used).
-      shuffle: Whether to shuffle the data. Default: True.
-          If set to False, sorts the data in alphanumeric order.
-      seed: Optional random seed for shuffling.
-      follow_links: Whether to visits subdirectories pointed to by symlinks.
+        directory: Directory where the data is located.
+            If `labels` is `"inferred"`, it should contain
+            subdirectories, each containing files for a class.
+            Otherwise, the directory structure is ignored.
+        labels: Either `"inferred"`
+            (labels are generated from the directory structure),
+            `None` (no labels),
+            or a list/tuple of integer labels of the same size as the number
+            of valid files found in the directory.
+            Labels should be sorted according
+            to the alphanumeric order of the image file paths
+            (obtained via `os.walk(directory)` in Python).
+        formats: Allowlist of file extensions to index
+            (e.g. `".jpg"`, `".txt"`).
+        class_names: Only valid if `labels="inferred"`. This is the explicit
+            list of class names (must match names of subdirectories). Used
+            to control the order of the classes
+            (otherwise alphanumerical order is used).
+        shuffle: Whether to shuffle the data. Defaults to `True`.
+            If set to `False`, sorts the data in alphanumeric order.
+        seed: Optional random seed for shuffling.
+        follow_links: Whether to visits subdirectories pointed to by symlinks.
+        verbose: Whether the function prints number of files found and classes.
+            Defaults to `True`.
 
     Returns:
-      tuple (file_paths, labels, class_names).
-        file_paths: list of file paths (strings).
-        labels: list of matching integer labels (same length as file_paths)
-        class_names: names of the classes corresponding to these labels, in
-          order.
+        tuple (file_paths, labels, class_names).
+        - file_paths: list of file paths (strings).
+        - labels: list of matching integer labels (same length as file_paths)
+        - class_names: names of the classes corresponding to these labels, in
+        order.
     """
-    if labels != "inferred":
-        # in the explicit/no-label cases, index from the parent directory down.
-        subdirs = [""]
-        class_names = subdirs
-    else:
+    if labels == "inferred":
         subdirs = []
         for subdir in sorted(tf.io.gfile.listdir(directory)):
             if tf.io.gfile.isdir(tf.io.gfile.join(directory, subdir)):
@@ -545,20 +533,36 @@ def index_directory(
                     if subdir.endswith("/"):
                         subdir = subdir[:-1]
                     subdirs.append(subdir)
-        if not class_names:
-            class_names = subdirs
-        else:
-            if set(class_names) != set(subdirs):
+        if class_names is not None:
+            if not set(class_names).issubset(set(subdirs)):
                 raise ValueError(
                     "The `class_names` passed did not match the "
                     "names of the subdirectories of the target directory. "
-                    f"Expected: {subdirs}, but received: {class_names}"
+                    f"Expected: {subdirs} (or a subset of it), "
+                    f"but received: class_names={class_names}"
                 )
+            subdirs = class_names  # Keep provided order.
+    else:
+        # In the explicit/no-label cases, index from the parent directory down.
+        subdirs = [""]
+        if class_names is not None:
+            if labels is None:
+                raise ValueError(
+                    "When `labels=None` (no labels), argument `class_names` "
+                    "cannot be specified."
+                )
+            else:
+                raise ValueError(
+                    "When argument `labels` is specified, argument "
+                    "`class_names` cannot be specified (the `class_names` "
+                    "will be the sorted list of labels)."
+                )
+    class_names = subdirs
     class_indices = dict(zip(class_names, range(len(class_names))))
 
     # Build an index of the files
     # in the different class subfolders.
-    pool = multiprocessing.pool.ThreadPool()
+    pool = ThreadPool()
     results = []
     filenames = []
 
@@ -574,7 +578,18 @@ def index_directory(
         partial_filenames, partial_labels = res.get()
         labels_list.append(partial_labels)
         filenames += partial_filenames
-    if labels not in ("inferred", None):
+
+    if labels == "inferred":
+        # Inferred labels.
+        i = 0
+        labels = np.zeros((len(filenames),), dtype="int32")
+        for partial_labels in labels_list:
+            labels[i : i + len(partial_labels)] = partial_labels
+            i += len(partial_labels)
+    elif labels is None:
+        class_names = None
+    else:
+        # Manual labels.
         if len(labels) != len(filenames):
             raise ValueError(
                 "Expected the lengths of `labels` to match the number "
@@ -582,21 +597,15 @@ def index_directory(
                 f"{len(labels)} while we found {len(filenames)} files "
                 f"in directory {directory}."
             )
-        class_names = sorted(set(labels))
-    else:
-        i = 0
-        labels = np.zeros((len(filenames),), dtype="int32")
-        for partial_labels in labels_list:
-            labels[i : i + len(partial_labels)] = partial_labels
-            i += len(partial_labels)
-
-    if labels is None:
-        io_utils.print_msg(f"Found {len(filenames)} files.")
-    else:
-        io_utils.print_msg(
-            f"Found {len(filenames)} files belonging "
-            f"to {len(class_names)} classes."
-        )
+        class_names = [str(label) for label in sorted(set(labels))]
+    if verbose:
+        if labels is None:
+            io_utils.print_msg(f"Found {len(filenames)} files.")
+        else:
+            io_utils.print_msg(
+                f"Found {len(filenames)} files belonging "
+                f"to {len(class_names)} classes."
+            )
     pool.close()
     pool.join()
     file_paths = [tf.io.gfile.join(directory, fname) for fname in filenames]
@@ -607,8 +616,9 @@ def index_directory(
             seed = np.random.randint(1e6)
         rng = np.random.RandomState(seed)
         rng.shuffle(file_paths)
-        rng = np.random.RandomState(seed)
-        rng.shuffle(labels)
+        if labels is not None:
+            rng = np.random.RandomState(seed)
+            rng.shuffle(labels)
     return file_paths, labels, class_names
 
 
@@ -627,16 +637,16 @@ def index_subdirectory(directory, class_indices, follow_links, formats):
     """Recursively walks directory and list image paths and their class index.
 
     Args:
-      directory: string, target directory.
-      class_indices: dict mapping class names to their index.
-      follow_links: boolean, whether to recursively follow subdirectories
-        (if False, we only list top-level images in `directory`).
-      formats: Allowlist of file extensions to index (e.g. ".jpg", ".txt").
+        directory: string, target directory.
+        class_indices: dict mapping class names to their index.
+        follow_links: boolean, whether to recursively follow subdirectories
+            (if False, we only list top-level images in `directory`).
+        formats: Allowlist of file extensions to index (e.g. ".jpg", ".txt").
 
     Returns:
-      tuple `(filenames, labels)`. `filenames` is a list of relative file
-        paths, and `labels` is a list of integer labels corresponding to these
-        files.
+        tuple `(filenames, labels)`. `filenames` is a list of relative file
+            paths, and `labels` is a list of integer labels corresponding
+            to these files.
     """
     dirname = os.path.basename(directory)
     valid_files = iter_valid_files(directory, follow_links, formats)
@@ -656,15 +666,15 @@ def get_training_or_validation_split(samples, labels, validation_split, subset):
     """Potentially restict samples & labels to a training or validation split.
 
     Args:
-      samples: List of elements.
-      labels: List of corresponding labels.
-      validation_split: Float, fraction of data to reserve for validation.
-      subset: Subset of the data to return.
-        Either "training", "validation", or None. If None, we return all of the
-        data.
+        samples: List of elements.
+        labels: List of corresponding labels.
+        validation_split: Float, fraction of data to reserve for validation.
+        subset: Subset of the data to return.
+            Either `"training"`, `"validation"`, or `None`.
+            If `None`, we return all of the data.
 
     Returns:
-      tuple (samples, labels), potentially restricted to the specified subset.
+        tuple (samples, labels), potentially restricted to the specified subset.
     """
     if not validation_split:
         return samples, labels
@@ -675,11 +685,13 @@ def get_training_or_validation_split(samples, labels, validation_split, subset):
             f"Using {len(samples) - num_val_samples} " f"files for training."
         )
         samples = samples[:-num_val_samples]
-        labels = labels[:-num_val_samples]
+        if labels is not None:
+            labels = labels[:-num_val_samples]
     elif subset == "validation":
         io_utils.print_msg(f"Using {num_val_samples} files for validation.")
         samples = samples[-num_val_samples:]
-        labels = labels[-num_val_samples:]
+        if labels is not None:
+            labels = labels[-num_val_samples:]
     else:
         raise ValueError(
             '`subset` must be either "training" '
@@ -689,19 +701,20 @@ def get_training_or_validation_split(samples, labels, validation_split, subset):
 
 
 def labels_to_dataset(labels, label_mode, num_classes):
-    """Create a tf.data.Dataset from the list/tuple of labels.
+    """Create a `tf.data.Dataset` from the list/tuple of labels.
 
     Args:
-      labels: list/tuple of labels to be converted into a tf.data.Dataset.
-      label_mode: String describing the encoding of `labels`. Options are:
-      - 'binary' indicates that the labels (there can be only 2) are encoded as
-        `float32` scalars with values 0 or 1 (e.g. for `binary_crossentropy`).
-      - 'categorical' means that the labels are mapped into a categorical
-        vector.  (e.g. for `categorical_crossentropy` loss).
-      num_classes: number of classes of labels.
+        labels: list/tuple of labels to be converted into a `tf.data.Dataset`.
+        label_mode: String describing the encoding of `labels`. Options are:
+        - `"binary"` indicates that the labels (there can be only 2) are encoded
+            as `float32` scalars with values 0 or 1
+            (e.g. for `binary_crossentropy`).
+        - `"categorical"` means that the labels are mapped into a categorical
+            vector.  (e.g. for `categorical_crossentropy` loss).
+        num_classes: number of classes of labels.
 
     Returns:
-      A `Dataset` instance.
+        A `tf.data.Dataset` instance.
     """
     label_ds = tf.data.Dataset.from_tensor_slices(labels)
     if label_mode == "binary":
@@ -721,12 +734,12 @@ def check_validation_split_arg(validation_split, subset, shuffle, seed):
     """Raise errors in case of invalid argument values.
 
     Args:
-      validation_split: float between 0 and 1, fraction of data to reserve for
-        validation.
-      subset: One of "training", "validation" or "both". Only used if
-        `validation_split` is set.
-      shuffle: Whether to shuffle the data. Either True or False.
-      seed: random seed for shuffling and transformations.
+        validation_split: float between 0 and 1, fraction of data to reserve for
+            validation.
+        subset: One of `"training"`, `"validation"`, or `"both"`. Only used if
+            `validation_split` is set.
+        shuffle: Whether to shuffle the data. Either `True` or `False`.
+        seed: random seed for shuffling and transformations.
     """
     if validation_split and not 0 < validation_split < 1:
         raise ValueError(
@@ -748,4 +761,3 @@ def check_validation_split_arg(validation_split, subset, shuffle, seed):
             "provide a `seed` argument, to make sure that there is no "
             "overlap between the training and validation subset."
         )
-
